Module errors

Module errors 

Errors that can occur during middleware processing stage

Enums

ARError
Custom error type. Useful for logging and debugging different kinds of errors. This type can be converted to Actix Error, which defaults to InternalServerError